#
# spec file for package libheif
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%define gdk_pixbuf_binary_version 2.10.0
%bcond_with x265
%bcond_with kvazaar
%bcond_with openh264
%bcond_with openjpeg
%bcond_with openjph
%bcond_with svtenc
%if 0%{?suse_version} > 1500
%ifarch aarch64 riscv64 x86_64
%bcond_without svtenc
%endif
%bcond_without openjpeg
%endif

%if 0%{?suse_version} && 0%{?suse_version} < 1600
%global force_gcc_version 13
%endif

Name:           libheif
Version:        1.19.5
Release:        1.1
Summary:        HEIF/AVIF file format decoder and encoder
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Other
URL:            https://github.com/strukturag/libheif
Source0:        %{url}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
BuildRequires:  chrpath
BuildRequires:  cmake >= 3.25
BuildRequires:  fdupes
BuildRequires:  gcc%{?force_gcc_version}-c++ >= 9
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(aom)
BuildRequires:  pkgconfig(dav1d)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libjpeg)
%if %{with openjpeg}
BuildRequires:  pkgconfig(libopenjp2)
%endif
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libwebp)
%if %{with kvazaar}
BuildRequires:  pkgconfig(kvazaar)
%endif
%if %{with openh264}
BuildRequires:  pkgconfig(openh264)
%endif
%if %{with openjph}
BuildRequires:  pkgconfig(openjph)
%endif
BuildRequires:  pkgconfig(rav1e)
%if %{with svtenc}
BuildRequires:  pkgconfig(SvtAv1Enc)
%endif
%if %{with x265}
BuildRequires:  pkgconfig(libde265)
BuildRequires:  pkgconfig(x265)
%endif
%if %{with test}
BuildArch:      noarch
%endif

%description
libheif is an ISO/IEC 23008-12:2017 HEIF and AVIF (AV1 Image File Format) file
format decoder and encoder.

HEIF and AVIF are new image file formats employing HEVC (H.265) or AV1 image
coding, respectively, for the best compression ratios currently possible.

%package -n libheif1
Summary:        HEIF/AVIF file format decoder and encoder
Group:          System/Libraries

%description -n libheif1
libheif is an ISO/IEC 23008-12:2017 HEIF and AVIF (AV1 Image File Format) file
format decoder and encoder.

HEIF and AVIF are new image file formats employing HEVC (H.265) or AV1 image
coding, respectively, for the best compression ratios currently possible.

For AVIF libaom, dav1d, or rav1e are used as codecs. HEIF support is not
provided.

%package aom
Summary:        Plugin AOM encoder and decoder for AVIF
Group:          System/Libraries
Supplements:    libheif1
Requires:       libheif1 = %{version}-%{release}

%description aom
This plugin provides the AOM encoder and decoder for AVIF to libheif. Packaged separately
so that the libraries it requires are not pulled in by default by libheif.

%package dav1d
Summary:        Plugin dav1d decoder for AVIF
Group:          System/Libraries
Supplements:    libheif1
Requires:       libheif1 = %{version}-%{release}

%description dav1d
This plugin provides the dav1d encoder for AVIF to libheif. Packaged separately
so that the libraries it requires are not pulled in by default by libheif.

%package ffmpeg
Summary:        Plugin FFMPEG decoder (HW acc) for HEIC
Group:          System/Libraries
Supplements:    libheif1
Requires:       libheif1 = %{version}-%{release}

%description ffmpeg
This plugin provides the FFMPEG decoder (HW acc) for HEIC to libheif. Packaged separately
so that the libraries it requires are not pulled in by default by libheif.

%package jpeg
Summary:        Plugin encoder and decoder for JPEG in HEIF
Group:          System/Libraries
Supplements:    libheif1
Requires:       libheif1 = %{version}-%{release}

%description jpeg
This plugin provides the encoder and decoder for JPEG in HEIF to libheif. Packaged separately
so that the libraries it requires are not pulled in by default by libheif.

%if %{with kvazaar}
%package kvazaar
Summary:        Plugin kvazaar encoder for HEIC
Group:          System/Libraries
Supplements:    libheif1
Requires:       libheif1 = %{version}-%{release}

%description kvazaar
This plugin provides the kvazaar encoder for HEIC to libheif. Packaged separately
so that the libraries it requires are not pulled in by default by libheif.
%endif

%if %{with openjpeg}
%package openjpeg
Summary:        Plugin OpenJPEG J2K encoder and decoder for JPEG-2000 in HEIF
Group:          System/Libraries
Supplements:    libheif1
Requires:       libheif1 = %{version}-%{release}

%description openjpeg
This plugin provides the OpenJPEG J2K encoder and decoder for JPEG to libheif. Packaged separately
so that the libraries it requires are not pulled in by default by libheif.
%endif

%if %{with openh264}
%package openh264
Summary:        Plugin OpenH264 decoder in HEIF
Group:          System/Libraries
Supplements:    libheif1
Requires:       libheif1 = %{version}-%{release}

%description openh264
This plugin provides the OpenH264 decoder to libheif. Packaged separately
so that the libraries it requires are not pulled in by default by libheif.
%endif

%if %{with openjph}
%package openjph
Summary:        Plugin OpenJPH HT-J2K encoder in HEIF
Group:          System/Libraries
Supplements:    libheif1
Requires:       libheif1 = %{version}-%{release}

%description openjph
This plugin provides the OpenJPH HT-J2K encoder to libheif. Packaged separately
so that the libraries it requires are not pulled in by default by libheif.
%endif

%package rav1e
Summary:        Plugin rav1e encoder for AVIF
Group:          System/Libraries
Supplements:    libheif1
Requires:       libheif1 = %{version}-%{release}

%description rav1e
This plugin provides the rav1e encoder for AVIF to libheif. Packaged separately
so that the libraries it requires are not pulled in by default by libheif.

%if %{with svtenc}
%package svtenc
Summary:        Plugin SVT-AV1 encoder for AVIF
Group:          System/Libraries
Supplements:    libheif1
Requires:       libheif1 = %{version}-%{release}

%description svtenc
This plugin provides the SVT-AV1 encoder for AVIF to libheif. Packaged separately
so that the libraries it requires are not pulled in by default by libheif.
%endif

%if %{with x265}
%package HEIF
Summary:        Plugin for HEIF decoder and encoder
Group:          System/Libraries
Supplements:    libheif1
Requires:       libheif1 = %{version}-%{release}

%description HEIF
This plugin provides an decoder and encoder for HEIF to libheif. Packaged separately
so that the libraries it requires are not pulled in by default by libheif.
%endif

%package devel
Summary:        Devel Package for %{name}
Group:          Development/Libraries/C and C++
Requires:       libheif1 = %{version}-%{release}

%description devel
libheif is a ISO/IEC 23008-12:2017 HEIF file format decoder and encoder.
This package contains the header files.

%package -n gdk-pixbuf-loader-libheif
Summary:        GDK PixBuf Loader for %{name}
Group:          System/Libraries
Supplements:    (libheif1 and libgdk_pixbuf-2_0-0)
Requires:       libheif1 = %{version}-%{release}

%description -n gdk-pixbuf-loader-libheif
A ISO/IEC 23008-12:2017 HEIF file format decoder and encoder.

This package contains the GDK PixBuf Loader for %{name}.

%if %{with x265}
%package -n heif-examples
Summary:        Example binary programs for %{name}
Group:          Productivity/Graphics/Other
Requires:       libheif1 = %{version}-%{release}

%description -n heif-examples
A ISO/IEC 23008-12:2017 HEIF file format decoder and encoder.

This package contains example binary programs for %{name}.

%package -n heif-thumbnailer
Summary:        Thumbnailer for HEIF/AVIF image files
Group:          Productivity/Graphics/Other
Supplements:    libheif1
Requires:       libheif1 = %{version}-%{release}

%description -n heif-thumbnailer
Allows to show thumbnail previews of HEIF and AVIF images using %{name}.
%endif

%prep
%autosetup -p1

%build
# https://github.com/strukturag/libheif/issues/1281
sed -i '/add_libheif_test(encode)/d' tests/CMakeLists.txt
%cmake \
%if 0%{?force_gcc_version}
	-DCMAKE_CXX_COMPILER="/usr/bin/g++-%{force_gcc_version}" \
%endif
%if %{with test}
	--preset=testing \
%else
	--preset=release \
	-DWITH_AOM_DECODER=ON \
	-DWITH_AOM_DECODER_PLUGIN=ON \
	-DWITH_AOM_ENCODER=ON \
	-DWITH_AOM_ENCODER_PLUGIN=ON \
	-DWITH_DAV1D=ON \
	-DWITH_DAV1D_PLUGIN=ON \
%if %{with x265}
	-DWITH_X265=ON \
	-DWITH_LIBDE265=ON \
	-DWITH_X265_PLUGIN=ON \
	-DWITH_LIBDE265_PLUGIN=ON \
	-DWITH_EXAMPLES=ON \
%else
	-DWITH_LIBDE265=OFF \
	-DWITH_X265=OFF \
	-DWITH_EXAMPLES=OFF \
%endif
	-DWITH_RAV1E=ON \
	-DWITH_RAV1E_PLUGIN=ON \
%if %{with svtenc}
	-DWITH_SvtEnc=ON \
	-DWITH_SvtEnc_PLUGIN=ON \
%else
	-DWITH_SvtEnc=OFF \
%endif
	-DWITH_JPEG_DECODER=ON \
	-DWITH_JPEG_DECODER_PLUGIN=ON \
	-DWITH_JPEG_ENCODER=ON \
	-DWITH_JPEG_ENCODER_PLUGIN=ON \
	-DWITH_UNCOMPRESSED_CODEC=ON \
%if %{with kvazaar}
	-DWITH_KVAZAAR=ON \
	-DWITH_KVAZAAR_PLUGIN=ON \
%else
	-DWITH_KVAZAAR=OFF \
%endif
	-DWITH_OpenJPEG_DECODER=ON \
	-DWITH_OpenJPEG_DECODER_PLUGIN=ON \
	-DWITH_OpenJPEG_ENCODER=ON \
	-DWITH_OpenJPEG_ENCODER_PLUGIN=ON \
%if %{with openh264}
	-DWITH_OpenH264_DECODER=ON \
	-DWITH_OpenH264_DECODER_PLUGIN=ON \
%else
	-DWITH_OpenH264_DECODER=OFF \
%endif
%if %{with openjph}
	-DWITH_OPENJPH_ENCODER=ON \
	-DWITH_OPENJPH_ENCODER_PLUGIN=ON \
%else
	-DWITH_OPENJPH_ENCODER=OFF \
%endif
	-DWITH_FFMPEG_DECODER=ON \
	-DWITH_FFMPEG_DECODER_PLUGIN=ON \
	-DCMAKE_SKIP_RPATH=ON \
	-DBUILD_TESTING=OFF \
	-DWITH_REDUCED_VISIBILITY=ON \
	-DWITH_DEFLATE_HEADER_COMPRESSION=ON \
	-DWITH_LIBSHARPYUV=ON \
	-DWITH_FUZZERS=OFF \
%if 0%{?suse_version} <= 1500
	-DCMAKE_CXX_FLAGS="-pthread" \
%endif
	-DPLUGIN_DIRECTORY=%{_libexecdir}/libheif \
%endif
	%nil
%cmake_build

%if %{with test}
%check
cd build
export LD_LIBRARY_PATH=$(pwd)/libheif
make test
%endif

%if !%{with test}

%install
%cmake_install
%if %{with x265}
#Install examples and man pages
install -d -m 0755 %{buildroot}%{_bindir} %{buildroot}%{_mandir}/man1/
for e in heif-dec \
         heif-enc \
         heif-info \
         heif-thumbnailer
         do
            install -m 0755 build/examples/$e %{buildroot}%{_bindir}/$e
            chrpath --delete %{buildroot}%{_bindir}/$e
            install -m 0644 examples/$e.1 %{buildroot}%{_mandir}/man1/$e.1
         done
%else
rm -f %{buildroot}%{_datadir}/mime/packages/avif.xml
rm -f %{buildroot}%{_datadir}/mime/packages/heif.xml
rm -f %{buildroot}%{_datadir}/thumbnailers/heif.thumbnailer
%endif
%fdupes -s %{buildroot}%{_includedir}

%post -n libheif1 -p /sbin/ldconfig
%postun -n libheif1 -p /sbin/ldconfig

%post -n gdk-pixbuf-loader-libheif
%{gdk_pixbuf_loader_post}

%postun -n gdk-pixbuf-loader-libheif
%{gdk_pixbuf_loader_postun}

%files -n libheif1
%license COPYING
%{_libdir}/libheif.so.*
%dir %{_libexecdir}/libheif

%files aom
%{_libexecdir}/libheif/libheif-aomdec.so
%{_libexecdir}/libheif/libheif-aomenc.so

%files dav1d
%{_libexecdir}/libheif/libheif-dav1d.so

%files ffmpeg
%{_libexecdir}/libheif/libheif-ffmpegdec.so

%files jpeg
%{_libexecdir}/libheif/libheif-jpegdec.so
%{_libexecdir}/libheif/libheif-jpegenc.so

%if %{with kvazaar}
%files kvazaar
%{_libexecdir}/libheif/libheif-kvazaar.so
%endif

%if %{with openjpeg}
%files openjpeg
%{_libexecdir}/libheif/libheif-j2kdec.so
%{_libexecdir}/libheif/libheif-j2kenc.so
%endif

%if %{with openh264}
%files openh264
%{_libexecdir}/libheif/libheif-openh264dec.so
%endif

%if %{with openjph}
%files openjph
%{_libexecdir}/libheif/libheif-jphenc.so
%endif

%files rav1e
%{_libexecdir}/libheif/libheif-rav1e.so

%if %{with svtenc}
%files svtenc
%{_libexecdir}/libheif/libheif-svtenc.so
%endif

%if %{with x265}
%files HEIF
%{_libexecdir}/libheif/libheif-libde265.so
%{_libexecdir}/libheif/libheif-x265.so
%endif

%files devel
%doc README.md
%{_includedir}/libheif
%{_libdir}/libheif.so
%{_libdir}/cmake/libheif
%{_libdir}/pkgconfig/libheif.pc

%files -n gdk-pixbuf-loader-libheif
%{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}/loaders/*.so

%if %{with x265}
%files -n heif-examples
%{_bindir}/heif-convert
%{_bindir}/heif-dec
%{_bindir}/heif-enc
%{_bindir}/heif-info
%{_mandir}/man1/heif-dec.1%{?ext_man}
%{_mandir}/man1/heif-enc.1%{?ext_man}
%{_mandir}/man1/heif-info.1%{?ext_man}

%files -n heif-thumbnailer
%{_bindir}/heif-thumbnailer
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/heif.thumbnailer
%{_mandir}/man1/heif-thumbnailer.1%{?ext_man}
%endif

%endif

%changelog
* Wed Nov 20 2024 Arjen de Korte <suse+build@de-korte.org>
- update to 1.19.5:
  * fix heif_image_handle_is_premultiplied_alpha() #1394
- update to 1.19.4:
  * fix crash when encoding tiled unci images
  * fix crash in heif_context_encode_grid()
  * fix querying the preferred colorspace for monochroma AVIF files
  * error when using a chroma format or bit depth that is not supported
    by the Kvazaar plugin
  * output proper error message when memory allocation failed and use
    adapted security limits
  * heif-dec: do not show progress with option --quiet it given
* Fri Nov 15 2024 Arjen de Korte <suse+build@de-korte.org>
- Fix build for Tumbleweed
* Thu Nov 14 2024 Dirk Müller <dmueller@suse.com>
- cleanup
* Wed Nov 13 2024 pgajdos@suse.com
- build for 15:
  * openjpeg only for 16+
  * require correct gcc version
* Tue Nov 12 2024 Arjen de Korte <suse+build@de-korte.org>
- update to 1.19.3:
  * fixes a race condition that may lead to some image tiles not being
    included in the output image (#1379)
  * fix a potential crash when querying overlay image information
* Wed Nov  6 2024 Arjen de Korte <suse+build@de-korte.org>
- update to 1.19.2:
  * fix DLL symbol export for non MSVC-compilers on Windows
  * fix running the unit tests from the build directory when building
    with plugins
  * switch to catch2 testing framework. We can now check for prerequisites
    at runtime and skip tests accordingly
- Remove patch that is no longer needed
  - only-run-test-when-HEVC-encoder-available.patch
* Sat Nov  2 2024 Arjen de Korte <suse+build@de-korte.org>
- update to 1.19.1:
  * Fixes backwards compatibility of heif_context_set_maximum_image_size_limit()
- update to 1.19.0:
  * The major new feature in this decoding separate tiles of images and
    also encoding an image tile by tile. This allows to process
    high-resolution images that do not fit into memory. We support three
    tiling methods:
  - grid, which is the default tiling method used in most existing
    HEIC or AVIF images.
  - unci, which is the built-in tiling method of the ISO 23001-17
    uncompressed codec.
  - tili, which is a proprietary scheme with much less overhead than
    grid and which supports efficient streaming of high-resolution
    images over networks without having to download huge amounts of
    metadata. It also supports much larger images than possible with
    grid. As an extra, it supports the processing of multi-dimensional
    images, like 3D image cubes, or image sets addressed by several
    parameter dimensions.
  * decoding is faster, especially if you let libheif decide on the best
    colorspace to work in by passing heif_colorspace_unknown and
    heif_chroma_unknown to heif_decode_image(). It will then use the
    input colorspace and avoid unnecessary conversions.
  * support for multi-resolution pyramids (pymd) to show downscaled
    versions of high-resolution images
  * improved reader interface that enables to connect libheif to a
    network source. Libheif will request the portions of the image file
    that have to be downloaded from the server. This is especially
    useful in connection with the tiling / multi-resolution pyramid
    feature.
  * function to generate overlay images
  * decoding progress is signaled to the client application and decoding
    can be cancelled
  * decoding of AVC encoded images through OpenH264
  * security limits can be changed to be able to read very large images
- Skip test when HEVC encoder is unavailable
  + only-run-test-when-HEVC-encoder-available.patch
* Mon Oct 21 2024 pgajdos@suse.com
- build *-test subpackage with multibuild for running the test suite
- added sources
  + _multibuild
* Mon Aug 19 2024 Manfred Hollstein <manfred.h@gmx.net>
- Add heif-convert to the files list of the heif-examples sub-package
* Thu Aug  8 2024 Arjen de Korte <suse+build@de-korte.org>
- update to 1.18.2:
  * fix regression that Exif orientation was not correctly reset when
    converting rotated HEIF (heif-dec)
  * swap Exif width/height when rotating image by 90 degrees
  * fix memory leak in OpenJPEG decoding plugin
  * pay attention to DESTDIR variable when installing heif-convert symlink
* Sat Jul 27 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.18.1:
  * Fix libbrotlidec pkg-config requires
  * tiff: Fix wrong type for "seekTIFF" function.
  * fix 32bit compiler warnings in box.cc
  * fix memory leaks in Brotli decoder
* Wed Jul 10 2024 Arjen de Korte <suse+build@de-korte.org>
- update to 1.18.0:
  * now reads images generated by iOS 18
  * heif-convert has been renamed to heif-dec
  * encoding: property item boxes with identical content are reused
  * support ISO 23001-17 version 1 uncC minimized headers
  * support ISO 23001-17 images with 'deflate', 'zlib' and Brotli
    compression
  * heif-enc can read TIFF images
  * API functions to read/write raw items and item properties
  * many bug fixes and smaller enhancements
- Remove libheif-svtav1.patch: no longer needed
* Thu Apr 18 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add libheif-svtav1.patch: Fix compilation with libsvtav1 2.0.0.
* Wed Jan  3 2024 Dirk Müller <dmueller@suse.com>
- update to 1.17.6:
  * A couple of build fixes and bug fixes detected by fuzzing.
  * Corrects these issues:
  * CVE-2023-49462 - #1043
  * CVE-2023-49463 - #1042
- drop libheif-CVE-2023-49462.patch,
  libheif-CVE-2023-49464.patch,
  libheif-CVE-2023-49460.patch: upstream
* Tue Dec 19 2023 pgajdos@suse.com
- security update
- added patches
  fix CVE-2023-49460 [bsc#1217902], segmentation violation in decode_uncompressed_image()
  + libheif-CVE-2023-49460.patch
* Mon Dec 18 2023 olaf@aepfle.de
- sync ExclusiveArch with SVT-AV1
- move HEIF plugins from examples to separate package
- make sure all subpackages use the same libheif1 ABI
* Tue Dec 12 2023 olaf@aepfle.de
- remove usage of presets to allow any cmake
- remove plugin conditional, to provide plugins on Leap as well
- remove rav1e conditional, because it is always available
* Mon Dec 11 2023 pgajdos@suse.com
- security update
- added patches
  fix CVE-2023-49462 [bsc#1217898], read16 segv
  + libheif-CVE-2023-49462.patch
  fix CVE-2023-49464 [bsc#1217900], UAF
  + libheif-CVE-2023-49464.patch
* Wed Nov 22 2023 Dirk Müller <dmueller@suse.com>
- update to 1.17.5:
  * Fixes installation of the Gnome "heif.thumbnailer" config
    file.
* Mon Nov 20 2023 Dirk Müller <dmueller@suse.com>
- update to 1.17.4:
  * ispe boxes in AVIF images with clap boxes were written with
    the wrong size (would only happen with svt-av1 encoder),
    always output MIAF brand for AVIF images
  * fix kvazaar encoding with odd image sizes and encodings with
    non-4:2:0 chroma
* Fri Nov  3 2023 Arjen de Korte <suse+build@de-korte.org>
- update to 1.17.3
  * Bug fix #1026: corrected transform box generation for
    heif_orientation_flip_vertically and
    heif_orientation_rotate_90_cw_then_flip_vertically
- update to 1.17.2:
  * #1010 loading of HEIF files with extra zero bytes at the end
  * #1015 / #1017 default nclx values now match sRGB
  * support JPEG2000 images with alpha channel
  * various smaller fixes
* Thu Oct 19 2023 Arjen de Korte <suse+build@de-korte.org>
- update to 1.17.1:
  * fix issue of loading images with premultiplied alpha channel
  * correctly set compatible_version for macOS dylib builds
  * fix loading HDR PNGs, but encoding them as 8-bit SDR
  * fix saving AVIF with alpha using the SVT-AV1 encoder
- cmake-presets version 3 requires cmake >= 3.21
* Tue Oct 17 2023 Arjen de Korte <suse+build@de-korte.org>
- update to 1.17.0:
  * Kvazaar encoder (HEIC) as alternative to x265
  * ffmpeg decoder (HEIC) decoding with potential hardware decoder support
  * jpegdec / jpegenc codecs for JPEG in HEIF
  * j2kdec, j2kenc codecs for JPEG-2000 in HEIF (still experimental)
  * added support for region masks
  * added support for alpha channels in images decoded with JS/WASM
  * heif-enc and heif-convert can be called with only input filenames,
    input and output filename, or with -o option. This makes the use of the
    two command more consistent.
  * added 4:2:2 <-> 4:4:4 color conversion with bilinear upscaling / average
    filtering
  * heif_context_get_image_handle() can now also access non-top-level images
  * add script to build Android libraries for all platforms
  * known bugs have been fixed
* Mon May 22 2023 Arjen de Korte <suse+build@de-korte.org>
- update to 1.16.2:
  * adds an option to heif-convert to set the PNG compression level
  * fixes a few build issues with some compilers
  * fixes the --encoder option in heif-enc
  * fixes heif_item_get_properties_of_type and
    heif_item_get_transformation_properties
* Wed May  3 2023 Arjen de Korte <suse+build@de-korte.org>
- Package the optional plugins in separate packages, so it is possible
  to install a minimal version of the library without pulling in the
  libraries needed by the plugins only.
- BuildRequires pkgconfig(libwebp) as it is required to make sharp-yuv
  work.
* Wed May  3 2023 Dirk Müller <dmueller@suse.com>
- update to 1.16.1:
  * Small maintenance update that fixes building the gdk-pixbuf
    loader.
  * The source package name has also been changed back to the old
    naming scheme.
  * Support for HEIFv2 regions (rgan) and user annotations
    (udes). This enables to annotate regions in the image with
    several geometric primitives and assign user text
    descriptions to them. Thank you @bradh for the contributions.
    Mask support will be added soon.
  * Previously, chroma was downsampled and upsampled with a
    simple nearest-neighbor method. We now included the sharp-yuv
    chroma downsampling algorithm. This gives improved image
    quality when images are downsampled to 4:2:0 and upsampled
    with bilinear interpolation. Thank you @maryla-uc for the
    contributions.
  * The bilinear chroma upsampling and averaging downsampling
    algorithms are also new. You can choose what to use.
  * We added experimental support for decoding uncompressed
    images according to ISO/IEC 23001-17:2023. This is work in
    progress and currently decoding only. Thank you @bradh for
    the contributions.
  * There are new APIs to query the image transformations. Thus,
    you may choose to get the original image and apply the
    transformations yourself.
  * A longstanding bug writing non-compliant 'ispe' boxes (image
    size) has been fixed. Files should be standard compliant now.
  * When building binary packages, you can now make use of a
    CMake presets to set a default configuration.
  * The deprecated autotools build files have been removed.
* Thu Mar 30 2023 Arjen de Korte <suse+build@de-korte.org>
- update to 1.15.2
  * Fixes an incompatibility with AOM v3.6.0.
  * A couple of smaller fixes.
* Tue Feb 28 2023 Manfred Hollstein <manfred.h@gmx.net>
- Remove no longer existing files avif.xml and heif.xml from the
  files list
* Thu Feb 16 2023 Arjen de Korte <suse+build@de-korte.org>
- update to 1.15.1
  * fix compilation without plugins
- update to 1.15.0
  * codec plugin system now also works with Windows
  * heif_convert: manually choose which decoder should be used
  * support for CLLI (content light level box), MDCV (mastering
    display colour volume), PASP (pixel aspect) information
  * ICC profile support in gdk-pixbuf loader
  * various fixes
- build with plugins enabled on Tumbleweed
- remove upstreamed patches
  - 2ca02a128b2f76f7f293aa86a2ce1e04a8306c65.patch
  - b6812284a2d70f29a5121ec3dbe652da07fdbbb7.patch
* Thu Feb  2 2023 Manfred Hollstein <manfred.h@gmx.net>
- Use chrpath during build to delete otherwise illegal runtime
  directories stored as RPATH in the executables
* Fri Jan 27 2023 Dirk Müller <dmueller@suse.com>
- add 2ca02a128b2f76f7f293aa86a2ce1e04a8306c65.patch
    b6812284a2d70f29a5121ec3dbe652da07fdbbb7.patch: (bsc#1206945)
  * replace internal API with public API and fix typo (Fixes #745)
* Fri Jan 27 2023 Arjen de Korte <suse+build@de-korte.org>
- The fix for rpath error for the examples sub-package was mistakenly
  moved
* Fri Jan 20 2023 Arjen de Korte <suse+build@de-korte.org>
- Add missing BuildRequires for SVT-AV1 support for Tumbleweed (only
  for x86_64)
* Sun Jan 15 2023 Arjen de Korte <suse+build@de-korte.org>
- Disable dynamic plugin interface and build plugins statically instead
  (boo#1206945)
* Sat Jan  7 2023 Dirk Müller <dmueller@suse.com>
- update to v1.14.2:
  * A function name typo in the C++ wrapper was corrected in v1.14.1, but
    the old function name should not have been removed from the API
  * (ColorProfile_nclx::set_color_primaries()). The old name is added to the
    API again in this release.
* Tue Jan  3 2023 Dirk Müller <dmueller@suse.com>
- update to v1.14.1:
  * various issues is the build system
  * encoding images smaller than 64x64 with svt-av1
  * the 'quality' parameter for svt-av1
  * a potentially wrong image orientation for PNG inputs
  * crash on non-null terminated XMP input
  * HDR RGB to YCbCr conversion coefficients for limited range coefficients
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 1.14.0:
  * adds SVT-AV1 encoder as AVIF backend
  * dynamic plugin interface for installing codecs independently from libheif (currently Unix only)
  * add XMP header compression (using zlib)
  * library should now be initialized with heif_init()
  * heif_convert: extract EXIF and XMP to separate files
  * heif_enc: add benchmarking function to compare codecs
  * copy EXIF/XMP between HEIC/AVIF files and JPEG/PNG in all kinds of combinations
  * remove EXIF orientation tag from input when converting to HEIC/AVIF and
  * generate irot/imir boxes matching the input orientation
* Thu Nov  3 2022 Yifan Jiang <yfjiang@suse.com>
- The newly added thumbnailer is not only useful for gnome, so
  rename the sub-package gnome-heif-thumbnailer to heif-thumbnailer
  before its debut
- Supplement libeheif1 with heif-thumbnailer
* Tue Nov  1 2022 Andreas Schneider <asn@cryptomilk.org>
- Create a gnome-heif-thumbnailer sub-package (boo#1204865)
* Mon Oct 31 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.13.0:
  * pay attention to the correct chroma sample positions
  * heif_image now holds a list of decoding warnings
  * use AOM AOM_USAGE_ALL_INTRA mode instead of AOM_USAGE_GOOD_QUALITY
  * 'strict' decoding mode with more checks for standard conformity of input
  * support for EXIF data >64k in JPEG output
  * proper library initialization and cleanup
  * separate quality settings for alpha channel (AOM)
  * improve color conversion speed (no lroundf)
  * build and packaging fixes
- Remove 0f8496f22d284e1a69df12fe0b72f375aed31315.patch: contained
- boo#1204865: No HEIC image preview in nautilus fixed by update
* Fri Aug 26 2022 Andreas Schneider <asn@cryptomilk.org>
- Support version 1.0.0 of dav1d
- Added 0f8496f22d284e1a69df12fe0b72f375aed31315.patch
* Fri Aug 12 2022 David Haller <dnh@opensuse.org>
- Fix rpath error for the examples sub-package
* Fri May 27 2022 Stanislav Brabec <sbrabec@suse.com>
- Add missing gdk-pixbuf loader scriptlets (bsc#1199987).
- Recommend gdk-pixbuf-loader-libheif whenever both related
  packages are installed.
* Fri Jun 11 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.12.0:
  + Check for MIAF conformance and add as compatible brand.
  + Signaling of premultiplied alpha.
  + Parse AV1 obu_sequence_header for av1C box.
  + Write pixi box in AVIFs.
  + Save alpha as monochrome in AVIF if possible.
  + Many build fixes.
* Wed Apr  7 2021 Dirk Müller <dmueller@suse.com>
- update to 1.11.0:
  * fix writing ispe box in HEIFs
  * nclx output profile encoding parameters
  * change the way nclx profiles is written so that macOS can read them
  * API for listing file brands and checking file type
  * fix heif_image_handle_get_depth_image_representation_info()
* Fri Jan  8 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add baselibs.conf: generate libheif1-32bit, which is a new
  dependency for ImageMagick-32bit after that one now enabled
  libheif support.
* Fri Dec 25 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Build with dav1d and rav1e support, do this via:
  + Add pkgconfig(dav1d) BuildRequires.
  + Add conditional pkgconfig(rav1e) BuildRequires (currently
    Tumbleweed only).
- Drop libheif-lang Recommends: Package does not exist.
* Thu Dec 17 2020 malcolmlewis@opensuse.org
- Re-download tarball and check with osc service runall
  download_files, all ok.
* Wed Dec 16 2020 malcolmlewis@opensuse.org
- Updated to version 1.10.0:
  * New API: may access all (vendor-dependent) auxiliary images
    (e.g. hdrgainmap, semanticskinmatte, ...).
  * When ICC profile is present, will now write two color boxes
  (nclx and ICC) into AVIF files. Also reads files with two color
  boxes.
  * Alpha image is now saved as monochrome.
  * Loading of 16bit greyscale PNGs in heif_enc.
  * Deprecated heif_enc option "-E".
  * Remove dependency on alloca().
  * Bug fixes.
* Sun Nov  1 2020 malcolmlewis@opensuse.org
- Add build condition to enable additional options, codecs and
  example binaries.
- Remove rav1e and dav1d support for the moment as still WIP.
* Tue Oct 13 2020 Andreas Schneider <asn@cryptomilk.org>
- Fix the License
* Mon Oct 12 2020 Andreas Schneider <asn@cryptomilk.org>
- Only build with AV1-AVIF support
- Update to version 1.9.1
  * https://github.com/strukturag/libheif/releases/tag/v1.9.1
- fixed CVE-2020-23109 [bsc#1192382]
  (bca0162018df9a32d21c05aad1fa203881fa7813)
* Sun Jul  8 2018 plinnell@opensuse.org
- initial package for 1.3.2
